<?php
/**
 * The "in-sticky" template to display the content of the single post, page or attachment:
 * featured image and title placed inside content, title sticky at the bottom side of the image
 *
 * @package WordPress
 * @subpackage BLABBER
 * @since BLABBER 1.0.62
 */
?>
<article id="post-<?php the_ID(); ?>"
	<?php
	post_class( 'post_item_single'
		. ' post_type_' . esc_attr( get_post_type() ) 
		. ' post_format_' . esc_attr( str_replace( 'post-format-', '', get_post_format() ) )
	);
	blabber_add_seo_itemprops();
	?>
>
<?php

	do_action( 'blabber_action_before_post_data' );

	blabber_add_seo_snippets();

	// Single post thumbnail and title
	if ( is_singular( 'post' ) || is_singular( 'attachment' ) ) {
		$blabber_post_format = str_replace( 'post-format-', '', get_post_format() );
		$post_meta = in_array( $blabber_post_format, array( 'video' ) ) ? get_post_meta( get_the_ID(), 'trx_addons_options', true ) : false;
		$video_autoplay = ! empty( $post_meta['video_autoplay'] ) && ! empty( $post_meta['video_list'] ) && is_array( $post_meta['video_list'] ) && count( $post_meta['video_list'] ) == 1;
		ob_start();
		?>
		<div class="post_header_wrap<?php
			if ( has_post_thumbnail() || str_replace( 'post-format-', '', get_post_format() ) == 'image' ) {
				echo ' with_featured_image';
			}
		?>">
			<?php
			// Featured image
			blabber_show_post_featured_image( array(
			'popup'     => true,
			'class_avg' => in_array( $blabber_post_format, array( 'video' ) )
								? ( ! $video_autoplay
									? 'content_wrap' 
									: 'with_thumb post_featured_bg with_video with_video_autoplay'
									)
								: '',
			'autoplay'  => $video_autoplay,
			'post_meta' => $post_meta
			) );
			// Post title and meta
			blabber_show_post_title_and_meta();
			?>
		</div>
		<?php
		$blabber_post_header = ob_get_contents();
		ob_end_clean();
		$blabber_with_featured_image = blabber_is_with_featured_image( $blabber_post_header );
		if ( strpos( $blabber_post_header, 'post_featured' ) !== false
			|| strpos( $blabber_post_header, 'post_title' ) !== false
			|| strpos( $blabber_post_header, 'post_meta' ) !== false
		) {
			do_action( 'blabber_action_before_post_header' );
			blabber_show_layout( $blabber_post_header );
			do_action( 'blabber_action_after_post_header' );
		}
	}

	do_action( 'blabber_action_before_post_content' );

	// Post content
	?>
	<div class="post_content post_content_single entry-content" itemprop="mainEntityOfPage">
		<?php
		the_content();

		do_action( 'blabber_action_before_post_pagination' );

		wp_link_pages(
			array(
				'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'blabber' ) . '</span>',
				'after'       => '</div>',
				'link_before' => '<span>',
				'link_after'  => '</span>',
				'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'blabber' ) . ' </span>%',
				'separator'   => '<span class="screen-reader-text">, </span>',
			)
		);

		// Taxonomies and share
		if ( is_single() && ! is_attachment() ) {

			ob_start();

			// Post taxonomies
			the_tags( '<span class="post_meta_item post_tags"><span class="post_meta_label">' . esc_html__( 'Tags:', 'blabber' ) . '</span> ', '', '</span>' );

			// Share
			if ( blabber_is_on( blabber_get_theme_option( 'show_share_links' ) ) ) {
				blabber_show_share_links(
					array(
						'type'    => 'block',
						'caption' => '',
						'before'  => '<span class="post_meta_item post_share">',
						'after'   => '</span>',
					)
				);
			}

			$blabber_tags_output = ob_get_contents();

			ob_end_clean();

			if ( ! empty( $blabber_tags_output ) ) {

				do_action( 'blabber_action_before_post_meta' );

				blabber_show_layout( $blabber_tags_output, '<div class="post_meta post_meta_single">', '</div>' );

				do_action( 'blabber_action_after_post_meta' );

			}
		}
		?>
	</div><!-- .entry-content -->


	<?php
	do_action( 'blabber_action_after_post_content' );

	do_action( 'blabber_action_after_post_data' );
	?>
</article>
