<?php
/**
 * ThemeREX Addons Custom post type: Post (add options to the standard WP Post)
 *
 * @package WordPress
 * @subpackage ThemeREX Addons
 * @since v1.6.24
 */

// Don't load directly
if ( ! defined( 'TRX_ADDONS_VERSION' ) ) {
	die( '-1' );
}


// -----------------------------------------------------------------
// -- Post type setup
// -----------------------------------------------------------------

// Add options to the standard WP post
if (!function_exists('trx_addons_cpt_post_init')) {
	add_action( 'init', 'trx_addons_cpt_post_init' );
	function trx_addons_cpt_post_init() {
		
		// Add post's custom fileds
		trx_addons_meta_box_register('post', array(
			'general_section' => array(
				"title" => esc_html__('General', 'trx_addons'),
				"desc" => wp_kses_data( __('General options', 'trx_addons') ),
				"type" => "section"
			),
			"icon" => array(
				"title" => esc_html__("Post's icon", 'trx_addons'),
				"desc" => wp_kses_data( __('Select icon for the current post (used in some shortcodes)', 'trx_addons') ),
				"std" => '',
				"options" => array(),
				"style" => trx_addons_get_setting('icons_type'),
				"type" => "icons"
			),
			// Post format: Video
			'video_section' => array(
				"title" => esc_html__('Video', 'trx_addons'),
				"desc" => wp_kses_data( __('Options of the post format "Video"', 'trx_addons') ),
				"type" => "section"
			),
			"video_source" => array(
				"title" => esc_html__("Video source", 'trx_addons'),
				"desc" => wp_kses_data( __("Select the source of the video to be displayed in the post's header", 'trx_addons') ),
				"dependency" => array(
					'.editor-post-format select' => 'video'
				),
				"std" => 'manual',
				"options" => array(
					'manual'        => esc_html__( 'Manually specified videos', 'trx_addons' ),
					'recent_posts'  => esc_html__( 'Videos from recent posts', 'trx_addons' ),
					'related_posts' => esc_html__( 'Videos from related posts', 'trx_addons' ),
				),
				"type" => "select"
			),
			"video_total" => array(
				"title" => esc_html__("Total videos", 'trx_addons'),
				"dependency" => array(
					'.editor-post-format select' => 'video',
					"video_source" => array( 'recent_posts', 'related_posts' )
				),
				"min" => 1,
				"max" => 10,
				"std" => 4,
				"type" => "slider"
			),
			"video_without_cover" => array(
				"title" => esc_html__('Hide cover image', 'trx_addons'),
				"desc" => wp_kses_data( __("Don't show cover/featured image on the video player in the single post", 'trx_addons') ),
				"dependency" => array(
					'.editor-post-format select' => 'video'
				),
				"std" => 0,
				"type" => "checkbox"
			),
			"video_autoplay_archive" => array(
				"title" => esc_html__("Allow autoplay on the archive page", 'trx_addons'),
				"desc" => wp_kses_data( __('Autoplay video when an archive page or shortcode is loaded', 'trx_addons') ),
				"dependency" => array(
					'.editor-post-format select' => 'video'
				),
				"std" => 1,
				"type" => "checkbox"
			),
			"video_autoplay" => array(
				"title" => esc_html__("Allow autoplay on the single post", 'trx_addons'),
				"desc" => wp_kses_data( __("Autoplay video when a single post is loaded (if single video is specified in the list below) or when checkboxing between videos (if more than one video are specified in the list below)", 'trx_addons') ),
				"dependency" => array(
					'.editor-post-format select' => 'video'
				),
				"std" => 1,
				"type" => "checkbox"
			),
			"video_list" => array(
				"title" => esc_html__("Video list", 'trx_addons'),
				"desc" => wp_kses_data( __("Specify one or more videos to use in the shortcodes output, post header and blog archive", 'trx_addons') ),
				"dependency" => array(
					'.editor-post-format select' => 'video',
					"video_source" => 'manual'
				),
				"clone" => false,
				"std" => array(array()),
				"type" => "group",
				"fields" => array(
					"image" => array(
						"title" => esc_html__("Cover image", 'trx_addons'),
						"desc" => wp_kses_data( __("Select an image to be used as a video cover", 'trx_addons') ),
						"class" => "trx_addons_column-1_3",
						"std" => "",
						"type" => "image"
					),
					"video_url" => array(
						"title" => esc_html__("Video URL", 'trx_addons'),
						"desc" => wp_kses_data( __('Specify URL to show a videoplayer from Youtube, Vimeo or other compatible video hosting', 'trx_addons') ),
						"class" => "trx_addons_column-1_3",
						"std" => "",
						"type" => "text"
					),
					"video_embed" => array(
						"title" => esc_html__("Video embed code", 'trx_addons'),
						"desc" => wp_kses_data( __('or paste embed code', 'trx_addons') ),
						"class" => "trx_addons_column-1_3",
						"std" => "",
						"type" => "textarea"
					)
				)
			),
		));
	}
}

// Open wrapper around single post video
if (!function_exists('trx_addons_cpt_post_before_video_sticky')) {
	add_action( 'trx_addons_action_before_single_post_video', 'trx_addons_cpt_post_before_video_sticky', 10, 1 );
	function trx_addons_cpt_post_before_video_sticky( $args = array() ) {
		if ( ! empty( $args['singular'] ) || ! empty( $args['singular_extra'] ) ) {
			$post_meta = get_post_meta( get_the_ID(), 'trx_addons_options', true );
			if ( ! empty( $post_meta['video_sticky'] ) ) {
				?>
				<div class="trx_addons_video_sticky">
					<div class="trx_addons_video_sticky_inner">
				<?php
				$GLOBALS['TRX_ADDONS_STORAGE']['video_sticky_opened'] = true;
			}

		}
	}
}

// Close wrapper around single post video
if (!function_exists('trx_addons_cpt_post_after_video_sticky')) {
	add_action( 'trx_addons_action_after_single_post_video', 'trx_addons_cpt_post_after_video_sticky', 10, 1 );
	function trx_addons_cpt_post_after_video_sticky( $args = array() ) {
		if ( ! empty( $GLOBALS['TRX_ADDONS_STORAGE']['video_sticky_opened'] ) ) {
			?>
				</div>
				<span class="trx_addons_video_sticky_close trx_addons_button_close" tabindex="0"><span class="trx_addons_button_close_icon"></span></span>
			</div>
			<?php
			$GLOBALS['TRX_ADDONS_STORAGE']['video_sticky_opened'] = false;
		}
	}
}



// Modify featured args - add video (if specified)
if (!function_exists('trx_addons_cpt_post_args_featured')) {
	add_filter( 'trx_addons_filter_args_featured', 'trx_addons_cpt_post_args_featured', 10, 3 );
	function trx_addons_cpt_post_args_featured( $featured_args, $sc='', $args=array() ) {
		if ( get_post_type() == 'post' && ! isset( $featured_args['autoplay'] ) ) {
			$post_format = str_replace( 'post-format-', '', get_post_format() );
			if ( $post_format == 'video' ) {
				$key = 'video_autoplay' . ( is_single() ? '' : '_archive' );
				$post_meta = get_post_meta( get_the_ID(), 'trx_addons_options', true );
				if ( ! empty( $post_meta[$key] ) && ! empty( $post_meta['video_list'] ) && is_array( $post_meta['video_list'] ) && count( $post_meta['video_list'] ) > 0 ) {
					$featured_args['autoplay'] = true;
				}
			}
		}
		return $featured_args;
	}
}

// Modify featured classes - add video (if specified)
if (!function_exists('trx_addons_cpt_post_post_featured_classes')) {
	add_filter( 'trx_addons_filter_post_featured_classes', 'trx_addons_cpt_post_post_featured_classes', 10, 3 );
	function trx_addons_cpt_post_post_featured_classes( $classes, $args=array(), $mode='' ) {
		if ( get_post_type() == 'post' && strpos( $classes, 'with_video_autoplay' ) === false ) {
			$post_format = str_replace( 'post-format-', '', get_post_format() );
			if ( $post_format == 'video' ) {
				$post_meta = get_post_meta( get_the_ID(), 'trx_addons_options', true );
				if ( ! empty( $post_meta['video_autoplay'] ) && ! empty( $post_meta['video_list'] ) && is_array( $post_meta['video_list'] ) && count( $post_meta['video_list'] ) > 0 ) {
					$classes .= ' with_video_autoplay';
				}
			}
		}
		return $classes;
	}
}